@@ -28,7 +28,9 @@ from ubuntutools import subprocess
 from ubuntutools.harvest import Harvest
 from ubuntutools.question import Question, YesNoQuestion
 
-from ubuntutools.sponsor_patch.question import ask_for_manual_fixing, user_abort
+from ubuntutools.sponsor_patch.question import (ask_for_ignoring_or_fixing,
+                                                ask_for_manual_fixing,
+                                                user_abort)
 
 def _get_series(launchpad):
     """Returns a tuple with the development and list of supported series."""
@@ -270,16 +272,14 @@ class SourcePackage(object):
                 Logger.error(("%s is not an allowed series. It needs to be one "
                              "of %s.") % (self._changelog.distributions,
                                           ", ".join(allowed)))
-                ask_for_manual_fixing()
-                return False
+                return ask_for_ignoring_or_fixing()
         elif upload and upload.startswith("ppa/"):
             allowed = supported_series + [devel_series]
             if self._changelog.distributions not in allowed:
                 Logger.error(("%s is not an allowed series. It needs to be one "
                              "of %s.") % (self._changelog.distributions,
                                           ", ".join(allowed)))
-                ask_for_manual_fixing()
-                return False
+                return ask_for_ignoring_or_fixing()
         return True
 
     def check_version(self, previous_version):
@@ -292,8 +292,7 @@ class SourcePackage(object):
         if self._version <= previous_version:
             Logger.error("The version %s is not greater than the already "
                          "available %s.", self._version, previous_version)
-            ask_for_manual_fixing()
-            return False
+            return ask_for_ignoring_or_fixing()
         return True
 
     def check_sync_request_version(self, bug_number, task):
@@ -340,8 +339,8 @@ class SourcePackage(object):
         debdiff_file.writelines(debdiff)
         debdiff_file.close()
 
-    def is_fixed(self, bug_number):
-        """Make sure that the given bug number is closed.
+    def is_fixed(self, lp_bug):
+        """Make sure that the given Launchpad bug is closed.
 
         Returns true if the bug is closed. Returns false if the user wants to
         change something.
@@ -355,11 +354,15 @@ class SourcePackage(object):
             fixed_bugs = changes["Launchpad-Bugs-Fixed"].split(" ")
         fixed_bugs = [int(bug) for bug in fixed_bugs]
 
-        if bug_number not in fixed_bugs:
+        # Check if the given bug is marked as duplicate. In this case get the
+        # master bug.
+        while lp_bug.duplicate_of:
+            lp_bug = lp_bug.duplicate_of
+
+        if lp_bug.id not in fixed_bugs:
             Logger.error("Launchpad bug #%i is not closed by new version." % \
-                         (bug_number))
-            ask_for_manual_fixing()
-            return False
+                         (lp_bug.id))
+            return ask_for_ignoring_or_fixing()
         return True
 
     def _print_logs(self):
@@ -437,14 +440,12 @@ class SourcePackage(object):
 
         return lintian_filename
 
-    def sync(self, upload, bug_number, keyid):
+    def sync(self, upload, bug_number, requester):
         """Does a sync of the source package."""
 
         if upload == "ubuntu":
-            cmd = ["syncpackage", self._package, "-b", str(bug_number),
-                   "-V", str(self._version)]
-            if keyid is not None:
-                cmd += ["-k", keyid]
+            cmd = ["syncpackage", self._package, "-b", str(bug_number), "-f",
+                   "-s", requester, "-V", str(self._version)]
             Logger.command(cmd)
             if subprocess.call(cmd) != 0:
                 Logger.error("Syncing of %s %s failed.", self._package,
@@ -452,7 +453,7 @@ class SourcePackage(object):
                 sys.exit(1)
         else:
             # FIXME: Support this use case!
-            Logger.error("Uploading a synced package other than to ubuntu "
+            Logger.error("Uploading a synced package other than to Ubuntu "
                          "is not supported yet!")
             sys.exit(1)
         return True
