@@ -277,8 +277,7 @@ def sponsor_patch(bug_number, build, builder, edit, keyid, lpinstance, update,
                                                          previous_version)
 
         if successful:
-            #if source_package.sync(upload, bug_number, keyid):
-            if source_package.ack_sync(upload, task.get_lp_task(), launchpad):
+            if source_package.sync(upload, bug_number, bug.owner.name):
                 return
             else:
                 edit = True
@@ -312,7 +311,7 @@ def sponsor_patch(bug_number, build, builder, edit, keyid, lpinstance, update,
         source_package.generate_debdiff(dsc_file)
 
         # Make sure that the Launchpad bug will be closed
-        if not source_package.is_fixed(bug_number):
+        if not source_package.is_fixed(bug):
             continue
 
         if not source_package.check_target(upload, launchpad):
